taylor 2003/12/29 17:24:49
Modified: commons/src/java/org/apache/jetspeed/container
JetspeedContainerServlet.java
commons/src/java/org/apache/jetspeed/om/common/portlet
MutablePortletApplication.java
Log:
Changed name of a local portlet app from PORTLET_APP to LOCAL
Revision Changes Path
1.3 +1 -4
jakarta-jetspeed-2/commons/src/java/org/apache/jetspeed/container/JetspeedContainerServlet.java
Index: JetspeedContainerServlet.java
===================================================================
RCS file:
/home/cvs/jakarta-jetspeed-2/commons/src/java/org/apache/jetspeed/container/JetspeedContainerServlet.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- JetspeedContainerServlet.java 20 Oct 2003 03:44:32 -0000 1.2
+++ JetspeedContainerServlet.java 30 Dec 2003 01:24:49 -0000 1.3
@@ -71,9 +71,6 @@
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.jetspeed.factory.JetspeedPortletFactory;
-import org.apache.pluto.core.CoreUtils;
-import org.apache.pluto.core.InternalPortletRequest;
-import org.apache.pluto.core.InternalPortletResponse;
import org.apache.pluto.om.portlet.PortletDefinition;
// import org.apache.jetspeed.om.common.portlet.PortletDefinitionComposite;
1.3 +8 -8
jakarta-jetspeed-2/commons/src/java/org/apache/jetspeed/om/common/portlet/MutablePortletApplication.java
Index: MutablePortletApplication.java
===================================================================
RCS file:
/home/cvs/jakarta-jetspeed-2/commons/src/java/org/apache/jetspeed/om/common/portlet/MutablePortletApplication.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- MutablePortletApplication.java 29 Dec 2003 02:51:17 -0000 1.2
+++ MutablePortletApplication.java 30 Dec 2003 01:24:49 -0000 1.3
@@ -74,7 +74,7 @@
* Extends the <code>org.apache.pluto.om.portlet.PortletApplicationDefinition</code>
* interface adding mutator methods for those attributes that do not have them
* so as to make manipulating the portlet OM easier.
- * It has additional methods to make it easier to use/test within Jetspeed.
+ * It has additional methods to make it easier to use within Jetspeed.
*
* @author <a href="mailto:[EMAIL PROTECTED]">Scott T. Weaver</a>
* @version $Id$
@@ -128,7 +128,7 @@
* [EMAIL PROTECTED] MutablePortletApplication#WEBAPP} - A standard web
application, stored in the web application
* server's web application space.
* <p>
- * [EMAIL PROTECTED] MutablePortletApplication#PORTLET_APP} - A portlet
application stored within Jetspeed's web application.
+ * [EMAIL PROTECTED] MutablePortletApplication#LOCAL} - A local portlet
application stored within Jetspeed's web application.
* <p>
* @param type The type of portlet application.
*/
@@ -141,7 +141,7 @@
* [EMAIL PROTECTED] MutablePortletApplication#WEBAPP} - A standard web
application, stored in the web application
* server's web application space.
* <p>
- * [EMAIL PROTECTED] MutablePortletApplication#PORTLET_APP} - A portlet
application stored within Jetspeed's web application.
+ * [EMAIL PROTECTED] MutablePortletApplication#LOCAL} - A local portlet
application stored within Jetspeed's web application.
* <p>
* @return The type of portlet application.
*/
@@ -151,11 +151,11 @@
* Marks this application as a standard web application,
* stored in the web application server's web application space.
*/
- public static final int WEB_APP = 0;
+ public static final int WEBAPP = 0;
/**
* Marks this application as a portlet application,
* stored in Jetspeed managed portlet application space.
*/
- public static final int PORTLET_APP = 1;
+ public static final int LOCAL = 1;
}
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
@@ -151,11 +151,11 @@
/**
- * Marks this application as a portlet application,
+ * Marks this application as a LOCAL portlet application,
* stored in Jetspeed managed portlet application space.
*/